pub enum Rv32ZkneInstruction<Reg> {
Aes32Esi {
rd: Reg,
rs1: Reg,
rs2: Reg,
bs: Rv32AesBs,
},
Aes32Esmi {
rd: Reg,
rs1: Reg,
rs2: Reg,
bs: Rv32AesBs,
},
}Expand description
RISC-V RV32 Zkne instructions (AES encryption)
Variants
Aes32Esi
AES final round encryption step: SubBytes on one byte of rs2, rotated to the byte lane selected by bs, XOR’d into rs1.
rd = rs1 ^ rol32(SBOX[(rs2 >> (bs*8)) & 0xff] as u32, bs*8)
Aes32Esmi
AES middle round encryption step: SubBytes + partial MixColumns on one byte of rs2, rotated to the byte lane selected by bs, XOR’d into rs1.
rd = rs1 ^ rol32(MixColByte(SBOX[(rs2 >> (bs*8)) & 0xff]), bs*8)